@@ -1,23 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "folderarchiveaccountinfo.h"
 
-FolderArchiveAccountInfo::FolderArchiveAccountInfo()
-{
-}
+FolderArchiveAccountInfo::FolderArchiveAccountInfo() = default;
 
 FolderArchiveAccountInfo::FolderArchiveAccountInfo(const KConfigGroup &config)
 {
     readConfig(config);
 }
 
-FolderArchiveAccountInfo::~FolderArchiveAccountInfo()
-{
-}
+FolderArchiveAccountInfo::~FolderArchiveAccountInfo() = default;
 
 bool FolderArchiveAccountInfo::isValid() const
 {
